@@ -1098,6 +1098,19 @@ class VariableClUpdateOutdatedKernelPath(Variable):
     """
     value = "/var/lib/calculate/calculate-update/outdated_kernel"
 
+class VariableClUpdateSkipRbSet(Variable):
+    """
+    Пропусить revdep-rebuild
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["-R", "--skip-revdep-rebuild"]
+
+    def init(self):
+        self.label = _("Skip reverse dependencies check")
+        self.help = _("skip reverse dependencies check")
+
 class VariableClUpdateOutdatedKernelSet(ReadonlyVariable):
     """
     Есть наличие устаревшего ядра
